<?php
/* Quick check if server has new information */
require("config.php");

$last_update        = pg_escape_string($_REQUEST['last_update']);
$max_execution_time = (float)ini_get("max_execution_time");

$conn = pg_pconnect($dsn);

# Poll as long as possible to reduce number of requests
# Is it possible to use the PostgreSQL "LISTEN" in combination with select() in PHP?
$now = time();
$end = max($now + 2, $now + $max_execution_time - 2);

while(time() < $end) {
	$result = pg_query("SELECT value from state WHERE key = 'last_update' AND value > '$last_update'");
	if(pg_num_rows($result)) {
		echo 1;
		exit;
	}
	sleep(1);
}
echo 0;
?>
